<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Block Attachments
    Version ........ 0.7
    Purpose ........ Allows an admin to block any types of attachments

*******************************************************************************/
      global $username;
      $filename = SM_PATH . 'plugins/block_attach/blocked_attachments.php';
      if (file_exists($filename))
         include($filename);
      else
         return;
      $dot = strrpos($Args[7], "."); 
      $ext = strtolower(substr($Args[7],$dot+1));
      $s = "abcdefghijklmnopqrstuvwxyz1234567890_";
      for ($a = 0; $a < strlen($ext); $a++) {
         $pos = strpos($s, substr($ext,$a,1));
         if ($pos === false) {
            $ext = str_replace(substr($ext,$a,1),'',$ext);
            $a--;
         }
      }
      if (in_array(strtolower($username),$excluded)) return;
      if (in_array($ext,$blocked)) {
         bindtextdomain('block_attach', SM_PATH . 'plugins/block_attach/locale');
         if ($Args[1]['download link']['text'] == _("download") || $Args[1]['download link']['text'] == _("Download")) {
            textdomain('block_attach');
            $Args[1]['download link']['text'] = _("File Blocked");
            $Args[6] = SM_PATH . "plugins/block_attach/blocked.php";
            $Args[1]['download link']['href'] = SM_PATH . "plugins/block_attach/blocked.php";
            textdomain('squirrelmail');
         }
      }

      if (in_array($ext,$warning)) {
         if ($Args[1]['download link']['text'] == _("download") || $Args[1]['download link']['text'] == _("Download")) {
            $Args[6] = SM_PATH . "plugins/block_attach/blocked.php?startMessage=$Args[2]&&passed_id=$Args[3]&mailbox=$Args[4]&ent_id=$Args[5]";
            $Args[1]['download link']['href'] = SM_PATH . "plugins/block_attach/blocked.php?startMessage=$Args[2]&&passed_id=$Args[3]&mailbox=$Args[4]&ent_id=$Args[5]";
         }
      }
?>